# Python Logging Library v0.0.1 (2023-09-06)

The initial release of beta version of python log library.

Features:
- Interface to communication with the AWS CloudWatch.
- Interface to the communication with the FTP server.
- Interface to push debug level log message.
- Interface to push info level log message.
- Interface to push fatal level log message.
- Interface to push error level log message.
- Interface to push embedded device data.


# Python Logging Library v0.1.1 (2023-09-08)

The update had been done onto the library to improve the atomicity. 

Features:
- CloudWatch Interface update: enables user to choose the AWS CloudWatch interface that they wanted to connect with.
- FTP Server Interface update: enables user to choose the FTP server interface that they wanted to connect with.